Description: Ensure allocfail.sh is not deleted
  Everything in $TESTS gets cleaned, but this file should not be

Author: Wookey <wookey@debian.org>
Forwarded: https://github.com/ianlancetaylor/libbacktrace/issues/81
Last-Update: 2021-12-15

Index: libbacktrace-1.0/Makefile.am
===================================================================
--- libbacktrace-1.0.orig/Makefile.am
+++ libbacktrace-1.0/Makefile.am
@@ -540,7 +540,7 @@ check_PROGRAMS += $(BUILDTESTS)
 TESTS += $(BUILDTESTS)
 
 CLEANFILES = \
-	$(TESTS) *.debug elf_for_test.c edtest2_build.c gen_edtest2_build \
+	$(filter-out allocfail.sh,$(TESTS)) *.debug elf_for_test.c edtest2_build.c gen_edtest2_build \
 	*.dsyms *.fsyms *.keepsyms *.dbg *.mdbg *.mdbg.xz *.strip
 
 clean-local:
